<?php

namespace MIQID\Elementor\Core;

use Elementor\Widget_Base;
use MIQID\Elementor\Handler\{Address, Profile};
use ReflectionClass;

abstract class Widget_MIQID extends Widget_Base {

	public $_title;

	public function get_name() {
		return strtolower( strtr( get_class( $this ), [ '\\' => '_' ] ) );
	}

	public function get_title() {
		return sprintf( __( 'MIQID - %s' ),
			$this->_title ?? strtr( get_class( $this ), [ 'MIQID\\Elementor\\Widget\\' => '', '_' => ' ' ] )
		);
	}

	public function get_categories() {
		return [ 'miqid' ];
	}

	public function get_icon() {
		return 'eicon-text';
	}

	function getMIQIDFields() {
		$Classes = [
			Profile::class,
			Address::class,
		];
		$options = [];
		foreach ( $Classes as $i => $Class ) {
			if ( ! class_exists( $Class ) ) {
				continue;
			}

			$ClassShortName = ( new ReflectionClass( $Class ) )->getShortName();

			$options[ $i ] = [
				'label'   => __( $ClassShortName, 'miqid-core' ),
				'options' => [],
			];


			$obj      = $Class::Instance();
			$obj_data = [];
			if ( method_exists( $obj, 'jsonSerialize' ) ) {
				$obj_data = $obj->jsonSerialize();
			} else if ( ! empty( get_object_vars( $obj ) ) ) {
				$obj_data = get_object_vars( $obj );
			}

			foreach ( $obj_data as $key => $value ) {
				$optionKey                              = sprintf( '%s.%s', $ClassShortName, $key );
				$options[ $i ]['options'][ $optionKey ] = __( $key, 'miqid-core' );
			}
		}

		return $options;
	}

	function get_miqid_data( $miqid ) {
		$miqid = explode( '.', $miqid ?? '' );
		$class = array_shift( $miqid );
		$field = array_shift( $miqid );

		if ( ! class_exists( $class ) ) {
			return null;
		}

		$class = $class::Instance();
		if ( ! method_exists( $class, 'Get' ) ) {
			return null;
		}

		$object = $class->Get();
		if ( ! $object || ! property_exists( $object, $field ) ) {
			return null;
		}

		return $object->{$field};
	}

	function get_font_weights() {
		return [
			'100' => __( 'Thin, Hairline, Ultra-light, Extra-light' ),
			'200' => __( 'Light' ),
			'300' => __( 'Book' ),
			'400' => __( 'Regular, Normal, Plain, Roman, Standard' ),
			'500' => __( 'Medium' ),
			'600' => __( 'Semi-bold, Demi-bold' ),
			'700' => __( 'Bold' ),
			'800' => __( 'Heavy, Black, Extra-bold' ),
			'900' => __( 'Ultra-black, Extra-black, Ultra-bold, Heavy-black, Fat, Poster' ),
		];
	}

	function get_method_name( $key ) {
		return sprintf( 'get_%s', strtolower( preg_replace( [ '/([a-z\d])([A-Z])/', '/([^_])([A-Z][a-z])/' ], '$1_$2', $key ) ) );
	}

	function _register_css( ...$files ) {
		$class = new ReflectionClass( $this );
		$files = array_values( array_unique( array_merge( [ mb_strtolower( sprintf( '%s.css', $class->getShortName() ) ) ], $files ) ) );

		$path     = plugin_dir_path( __DIR__ ) . 'assets/css';
		$url      = plugin_dir_url( __DIR__ ) . 'assets/css';
		$handlers = [];
		foreach ( $files as $file ) {
			if ( file_exists( sprintf( '%s/%s', $path, $file ) ) ) {
				$filemtime = filemtime( sprintf( '%s/%s', $path, $file ) );
				$fileName  = basename( $file, '.js' );
				$handler   = implode( '_', array_unique( explode( '_', sprintf( '%s_%s', $this->get_name(), $fileName ) ) ) );

				wp_register_style( $handler, sprintf( '%s/%s', $url, $file ), null, date( 'Ymd-His', $filemtime ) );

				$handlers[] = $handler;
			}
		}

		return $handlers;
	}

	function _register_js( ...$files ) {
		$class = new ReflectionClass( $this );
		$files = array_values( array_unique( array_merge( [ mb_strtolower( sprintf( '%s.js', $class->getShortName() ) ) ], $files ) ) );

		$path     = plugin_dir_path( __DIR__ ) . 'assets/js';
		$url      = plugin_dir_url( __DIR__ ) . 'assets/js';
		$handlers = [];
		foreach ( $files as $file ) {
			if ( file_exists( sprintf( '%s/%s', $path, $file ) ) ) {
				$filemtime = filemtime( sprintf( '%s/%s', $path, $file ) );
				$fileName  = basename( $file, '.js' );
				$handler   = implode( '_', array_unique( explode( '_', sprintf( '%s_%s', $this->get_name(), $fileName ) ) ) );

				wp_register_script( $handler, sprintf( '%s/%s', $url, $file ), [ 'elementor-frontend', 'jquery' ], date( 'Ymd-His', $filemtime ), true );
				wp_localize_script( $handler, $fileName, [ 'admin-ajax' => admin_url( 'admin-ajax.php' ) ] );

				$handlers[] = $handler;
			}
		}

		return $handlers;
	}
}