<?php

namespace MIQID\Elementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Utils;
use MIQID\Elementor\Core\Widget_MIQID;

final class Dynamic_Images extends Widget_MIQID {

	public function get_icon() {
		return 'eicon-image';
	}

	protected function _register_controls() {

		$this->start_controls_section( 'content_section', [
			'label' => 'Content',
			'tab'   => Controls_Manager::TAB_CONTENT,
		] );

		$this->add_control( 'miqid', [
			'label'   => 'MiqId',
			'type'    => Controls_Manager::SELECT,
			'groups' => $this->getMIQIDFields(),
		] );

		$this->add_control( 'default_image', [
			'label'   => 'Default Image',
			'type'    => Controls_Manager::MEDIA,
			'dynamic' => [ 'active' => true ],
		] );

		$this->add_control( 'clickAction', [
			'label'   => 'Click action',
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'none'  => "None",
				'link'  => 'Link',
				'popup' => 'Popup',
			],
			'default' => 'none',
		] );

		$this->add_control( 'popupID', [
			'label'     => 'Post ID of popup',
			'condition' => [ 'clickAction' => 'popup' ],
			'type'      => Controls_Manager::TEXT,
			'dynamic'   => [ 'active' => true ],
		] );

		$this->add_control( 'link', [
			'label'     => 'Link',
			'condition' => [ 'clickAction' => 'link' ],
			'type'      => Controls_Manager::URL,
			'dynamic'   => [ 'active' => true ],
		] );

		$repeater = new Repeater();

		$repeater->add_control( 'clickAction', [
			'label'   => 'Click action',
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'none'  => "None",
				'link'  => 'Link',
				'popup' => 'Popup',
			],
			'default' => 'none',
		] );

		$repeater->add_control( 'popupID', [
			'label'     => 'Post ID of popup',
			'condition' => [ 'clickAction' => 'popup' ],
			'type'      => Controls_Manager::TEXT,
			'dynamic'   => [ 'active' => true ],
		] );

		$repeater->add_control( 'link', [
			'label'     => 'Link',
			'condition' => [ 'clickAction' => 'link' ],
			'type'      => Controls_Manager::URL,
			'dynamic'   => [ 'active' => true ],
		] );

		$repeater->add_control( 'match', [
			'label'   => 'Text Match',
			'type'    => Controls_Manager::TEXT,
			'dynamic' => [ 'active' => true ],
		] );

		$repeater->add_control( 'image', [
			'label'   => 'Display image',
			'type'    => Controls_Manager::MEDIA,
			'default' => [
				'url' => Utils::get_placeholder_image_src(),
			],
		] );

		$this->add_control( 'switch', [
			'label'         => 'Switch cases',
			'type'          => Controls_Manager::REPEATER,
			'default'       => [
				'title' => "Item #1",
			],
			'prevent_empty' => true,
			'fields'        => $repeater->get_controls(),
			'title_field'   => '{{{ match }}}',
		] );

		$this->end_controls_section();

		$this->start_controls_section( 'text_style', [
			'label' => 'Text',
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'text_color', [
			'label'     => 'Text Color',
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} .elementor-icon-list-text' => 'color: {{VALUE}};',
			],
		] );

		$this->end_controls_section();
	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		$miqid    = $settings["miqid"];
		$switch   = $settings['switch'];
		$case     = [
			'clickAction' => $settings['clickAction'],
			'popupID'     => $settings['popupID'],
			'link'        => $settings['link'],
			'image'       => $settings['default_image'],
		];
		$data     = $this->get_miqid_data( $miqid );

		$match = current( array_values(
			array_filter( $switch, function ( $case ) use ( $data ) {
				return preg_match( '/' . $case['match'] . '/i', $data );
			} )
		) );

		if ( ! empty( $match ) ) {
			$case = $match;
		}

		?>
        <div class="elementor-image miqid-dynamic-images">
			<?php switch ( $case['clickAction'] ) {
				case 'popup': ?>
                    <picture class="attachment-large size-large" onclick="elementorProFrontend.modules.popup.showPopup( { id: <?= $case['popupID'] ?? '' ?> } )">
                        <img src="<?= $case['image']['url'] ?>"/>
                    </picture>
					<?php break;
				case 'link': ?>
                    <a href="<?= $case['link']['url'] ?>" <?= $case['link']['is_external'] ? 'target="_blank"' : '' ?> <?= $case['link']['nofollow'] ? 'rel="nofollow"' : '' ?>>
                        <picture class="attachment-large size-large">
                            <img src="<?= $case['image']['url'] ?>"/>
                        </picture>
                    </a>
					<?php break;
				default: ?>
                    <picture class="attachment-large size-large">
                        <img src="<?= $case['image']['url'] ?>"/>
                    </picture>
					<?php break;
			}
			?>
        </div>
		<?php
	}

}