<?php

namespace MIQID\Elementor\Widget;

use Elementor\{Controls_Manager, Repeater};
use MIQID\Elementor\Core\Widget_MIQID;

final class Dynamic_Text extends Widget_MIQID {


	protected function _register_controls() {

		$this->start_controls_section(
			'content_section',
			[
				'label' => __( 'Content', 'miqid-elementor' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control( 'miqid', [
			'label'   => 'MiqId',
			'type'    => Controls_Manager::SELECT,
			'groups' => $this->getMIQIDFields(),
		] );

		$this->add_control( 'default_text', [
			'label'   => 'Default text',
			'type'    => Controls_Manager::TEXT,
			'dynamic' => [ 'active' => true ],
		] );

		$this->add_control( 'text_color', [
			'label'     => 'Text Color',
			'type'      => Controls_Manager::COLOR,
			'selectors' => [ '{{WRAPPER}}' => '{{VALUE}};' ],
		] );

		$this->add_control( 'icon', [
			'label'   => ( 'Icon' ),
			'type'    => Controls_Manager::ICONS,
			'default' => [ 'value' => 'fas fa-star' ],
		] );

		$this->add_control( 'icon_color', [
			'label'     => 'Icon Color',
			'type'      => Controls_Manager::COLOR,
			'selectors' => [ '{{WRAPPER}}' => '{{VALUE}};' ],
		] );

		// <editor-fold desc="Repeater">
		$repeater = new Repeater();

		$repeater->add_control( 'match', [
			'label'   => 'Text Match',
			'type'    => Controls_Manager::TEXT,
			'dynamic' => [ 'active' => true ],
		] );

		$repeater->add_control( 'text', [
			'label'   => 'Display text',
			'type'    => Controls_Manager::TEXT,
			'dynamic' => [ 'active' => true ],
		] );

		$repeater->add_control( 'text_color', [
			'label' => 'Text Color',
			'type'  => Controls_Manager::COLOR,
		] );

		$repeater->add_control( 'font_family', [
			'label' => 'Typography',
			'type'  => Controls_Manager::FONT,
		] );

		$this->add_control( 'switch', [
			'label'         => 'Switch cases',
			'type'          => Controls_Manager::REPEATER,
			'default'       => [
				[ 'text' => 'Case #1', ],
				[ 'text' => 'Case #2', ],
				[ 'text' => 'Case #3', ],
			],
			'prevent_empty' => true,
			'fields'        => $repeater->get_controls(),
			'title_field'   => '{{{ text }}}',
		] );
		// </editor-fold>

		$this->end_controls_section();

		$this->start_controls_section( 'icon_style',
			[
				'label' => 'Icon',
				'tab'   => Controls_Manager::TAB_STYLE,
			] );

		$this->add_control( 'icon_size', [
			'label'      => 'Icon size',
			'type'       => Controls_Manager::SLIDER,
			'size_units' => [ 'px' ],
			'range'      => [
				'px' => [
					'min'  => 0,
					'max'  => 100,
					'step' => 1,
				],
			],
			'default'    => [
				'unit' => 'px',
				'size' => 14,
			],
			'selectors'  => [
				'{{WRAPPER}} .elementor-icon-list-icon i' => 'font-size: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->end_controls_section();
	}

	protected function render() {

		$settings     = $this->get_settings_for_display();
		$miqid        = $settings["miqid"];
		$default_text = $settings["default_text"];
		$text_color   = $settings["text_color"];
		$icon         = $settings["icon"];
		$icon_color   = $settings['icon_color'];
		$switch       = $settings['switch'];
		$icon_size    = $settings['icon_size'];
		$font_family  = $settings["font_family"];

		$case = [];

		if ( ! empty( $miqid ) ) {
			$data = $this->get_miqid_data( $miqid );

			$case = current( array_values( array_filter( $switch, function ( $case ) use ( $data ) {
				return preg_match( '/' . $case['match'] . '/i', $data );
			} ) ) );
		}

		$template = '<ul class="elementor-icon-list-items ' . $this->get_name() . '">
    <li class="elementor-icon-list-item">
    	%%Icon%%
        <span class="elementor-icon-list-text">' . ( $case['text'] ?? $default_text ) . '</span>
    </li>
</ul>';

		$replace = [ '%%Icon%%' => '' ];

		if ( ! empty( $icon['value'] ) ) {
			$replace['%%Icon%%'] = '<span class="elementor-icon-list-icon"><i aria-hidden="true" class="' . $icon['value'] . '"></i></span>';
		}

		print strtr( $template, $replace );

		print '<style>
.elementor-element.elementor-element-' . $this->get_id() . ' .' . $this->get_name()
		      . ' {'
		      . ( ! empty( $text_color ) ? 'color: ' . $text_color . ';' : '' )
		      . ( ! empty( $font_family ) ? 'font-family: ' . $font_family . ';' : '' )
		      . '}
.elementor-element.elementor-element-' . $this->get_id() . ' .' . $this->get_name() . ' .elementor-icon-list-icon i'
		      . '{'
		      . ( ! empty( $icon_color ) ? 'color: ' . $icon_color . ';' : '' )
		      . ( ! empty( $icon_size ) ? 'font-size: ' . $icon_size['size'] . $icon_size['unit'] . ';' : '' )
		      . '}
</style>';
	}
}