<?php

namespace MIQID\Elementor\Widget;

use Elementor\{Controls_Manager, Icons_Manager, Repeater};
use MIQID\Elementor\Core\Widget_MIQID;

class IconList extends Widget_MIQID {

	protected function _register_controls() {

		$this->start_controls_section( 'content_section', [
			'label' => 'Content',
			'tab'   => Controls_Manager::TAB_CONTENT,
		] );

		$lines = new Repeater();

		$lines->add_control( 'text', [
			'label'   => 'Text',
			'type'    => Controls_Manager::TEXT,
			'dynamic' => [ 'active' => true ],
		] );

		$lines->add_control( 'default_icon', [
			'label' => 'Default Icon',
			'type'  => Controls_Manager::ICONS,
		] );

		$lines->add_control( 'miqid', [
			'label'   => 'MiqId',
			'type'    => Controls_Manager::SELECT,
			'groups' => $this->getMIQIDFields(),
		] );

		$lines->add_control( 'match', [
			'label'   => 'Match',
			'type'    => Controls_Manager::TEXT,
			'dynamic' => [ 'active' => false ],
		] );

		$lines->add_control( 'match_icon', [
			'label' => 'Match Icon',
			'type'  => Controls_Manager::ICONS,
		] );

		$this->add_control( 'lines', [
			'label'         => 'Lines',
			'type'          => Controls_Manager::REPEATER,
			'default'       => [
				[ 'text' => 'Line #1', ],
			],
			'prevent_empty' => true,
			'fields'        => $lines->get_controls(),
			'title_field'   => '{{{ text }}}',
		] );

		$this->end_controls_section();

	}

	protected function render() {
		$settings = $this->get_settings_for_display();
		?>
		<ul class="elementor-icon-list-items <?= $this->get_name() ?>">
			<?php
			foreach ( $settings['lines'] as $key => $line ) {

				$miqid    = $line['miqid'];
				$data     = null;
				$icon_str = null;

				if ( ! empty( $miqid ) ) {
					$data = $this->get_miqid_data( $miqid );
				}

				$icon = preg_match( '/' . $line['match'] . '/i', $data )
					? $line['match_icon']
					: $line['default_icon'];
				?>
				<li>
					<?php
					if ( ! empty( array_filter( $icon ) ) ) {
						print '<span class="elementor-icon-list-icon list-icon">';
						Icons_Manager::render_icon( $icon, [ 'aria-hidden' => 'true' ] );
						print '</span>';
					}
					?>
					<span class="elementor-icon-list-text"><?= $line["text"] ?></span>
				</li>
				<?php
			}
			?>
		</ul>
		<?php
	}
}