<?php

namespace MIQID\Elementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Typography;
use MIQID\Elementor\Core\Widget_MIQID;

class Input extends Widget_MIQID {

	public function __construct( $data = [], $args = null ) {
		parent::__construct( $data, $args );

		wp_register_style(
			$this->get_name(),
			plugin_dir_url( __DIR__ ) . 'assets/css/input.css',
			null,
			date( 'Ymd-His', filemtime( plugin_dir_path( __DIR__ ) . '/assets/css/input.css' ) )
		);

	}

	public function get_style_depends() {
		return [ $this->get_name() ];
	}

	protected function _register_controls() {
		$this->start_controls_section( 'content', [
			'label' => 'Content',
			'tab'   => Controls_Manager::TAB_CONTENT,
		] );

		$this->add_control( 'type', [
			'label'   => __( 'Type', 'miqid-elementor' ),
			'type'    => Controls_Manager::SELECT,
			'options' => [
				'text'     => __( 'Text', 'miqid-elementor' ),
				'password' => __( 'password', 'miqid-elementor' ),
				'hidden'   => __( 'Hidden', 'miqid-elementor' ),
				'email'    => __( 'Email', 'miqid-elementor' ),
				'number'   => __( 'number', 'miqid-elementor' ),
				'tel'      => __( 'tel', 'miqid-elementor' ),
				'url'      => __( 'url', 'miqid-elementor' ),

				'date'           => __( 'Date', 'miqid-elementor' ),
				'time'           => __( 'time', 'miqid-elementor' ),
				'datetime-local' => __( 'DateTime-Local', 'miqid-elementor' ),
				'month'          => __( 'month', 'miqid-elementor' ),
				'week'           => __( 'week', 'miqid-elementor' ),

				'checkbox' => __( 'Checkbox', 'miqid-elementor' ),
				'radio'    => __( 'radio', 'miqid-elementor' ),

				'color'  => __( 'Color', 'miqid-elementor' ),
				'file'   => __( 'File', 'miqid-elementor' ),
				'image'  => __( 'Image', 'miqid-elementor' ),
				'range'  => __( 'range', 'miqid-elementor' ),
				'reset'  => __( 'reset', 'miqid-elementor' ),
				'search' => __( 'search', 'miqid-elementor' ),
				'submit' => __( 'submit', 'miqid-elementor' ),
			],
		] );

		$this->add_control( 'label', [
			'label' => __( 'Label', 'miqid-elementor' ),
			'type'  => Controls_Manager::TEXT,
		] );

		$this->add_control( 'placeholder', [
			'label' => __( 'Placeholder', 'miqid-elementor' ),
			'type'  => Controls_Manager::TEXT,
		] );

		$this->add_control( 'required', [
			'label' => __( 'Required', 'miqid-elementor' ),
			'type'  => Controls_Manager::SWITCHER,
		] );

		$this->add_control( 'field', [
			'label'  => __( 'Field', 'miqid-elementor' ),
			'type'   => Controls_Manager::SELECT,
			'groups' => $this->getMIQIDFields(),
		] );

		$this->end_controls_section();

		// <editor-fold desc="Style">
		$this->start_controls_section( 'layout', [
			'label' => __( 'Layout', 'miqid-elementor' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'direction', [
			'label'   => __( 'Direction', 'miqid-elementor' ),
			'type'    => Controls_Manager::CHOOSE,
			'options' => [
				'horizontal' => [
					'title' => __( 'Horizontal' ),
					'icon'  => 'fas fa-grip-lines',
				],
				'vertical'   => [
					'title' => __( 'Vertical' ),
					'icon'  => 'fas fa-grip-lines-vertical',
				],
			],
			'default' => 'vertical',
		] );

		$this->end_controls_section();
		// </editor-fold>

		// <editor-fold desc="style_label">
		$this->start_controls_section( 'style_label', [
			'label' => __( 'Label', 'miqid-elementor' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'label_color', [
			'label'     => __( 'Color', 'miqid-elementor' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} label' => 'color: {{VALUE}}',
			],
		] );

		$this->add_group_control( Group_Control_Typography::get_type(), [
			'name'     => 'typography',
			'global'   => [
				'default' => Global_Typography::TYPOGRAPHY_PRIMARY,
			],
			'selector' => '{{WRAPPER}} label',
		] );

		$this->add_control( 'label_font_weight', [
			'label'     => __( 'Font-Weight', 'miqid-elementor' ),
			'type'      => Controls_Manager::SELECT,
			'options'   => $this->get_font_weights(),
			'default'   => '500',
			'selectors' => [
				'{{WRAPPER}} label' => 'font-weight: {{VALUE}}',
			],
		] );

		$this->add_control( 'label_padding', [
			'label'      => __( 'Padding', 'miqid-elementor' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} label' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->add_control( 'label_width', [
			'label'      => __( 'Padding', 'miqid-elementor' ),
			'type'       => Controls_Manager::SLIDER,
			'default'    => [
				'size' => 120,
				'unit' => 'px',
			],
			'size_units' => [ 'px', '%', 'em' ],
			'range'      => [
				'px' => [
					'min' => 10,
					'max' => 600,
				],
				'em' => [
					'min' => 0.1,
					'max' => 20,
				],
			],
			'selectors'  => [
				'{{WRAPPER}} label' => 'width: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->end_controls_section();
		// </editor-fold>

		// <editor-fold desc="style_input">
		$this->start_controls_section( 'style_input', [
			'label' => __( 'Input', 'miqid-elementor' ),
			'tab'   => Controls_Manager::TAB_STYLE,
		] );

		$this->add_control( 'input_padding', [
			'label'      => __( 'Padding', 'miqid-elementor' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} input' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );

		$this->add_control( 'input_border_color', [
			'label'     => __( 'Border Color', 'miqid-elementor' ),
			'type'      => Controls_Manager::COLOR,
			'selectors' => [
				'{{WRAPPER}} input' => 'border-color: {{VALUE}}',
			],
		] );

		$this->add_control( 'input_border_width', [
			'label'      => __( 'Border Width', 'miqid-elementor' ),
			'type'       => Controls_Manager::SLIDER,
			'default'    => [
				'size' => 1,
				'unit' => 'px',
			],
			'size_units' => [ 'px', 'em' ],
			'range'      => [
				'px' => [
					'min' => 0,
					'max' => 10,
				],
				'em' => [
					'min' => 0.1,
					'max' => 1,
				],
			],
			'selectors'  => [
				'{{WRAPPER}} input' => 'border-width: {{SIZE}}{{UNIT}};',
			],
		] );

		$this->add_control( 'input_border_style', [
			'label'     => __( 'Border Width', 'miqid-elementor' ),
			'type'      => Controls_Manager::SELECT,
			'options'   => [
				'solid'  => __( 'Solid', 'miqid-elementor' ),
				'double' => __( 'Double', 'miqid-elementor' ),
				'dotted' => __( 'Dotted', 'miqid-elementor' ),
			],
			'selectors' => [
				'{{WRAPPER}} input' => 'border-style: {{VALUE}};',
			],
		] );

		$this->add_control( 'input_border_radius', [
			'label'      => __( 'Border Radius', 'miqid-elementor' ),
			'type'       => Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%', 'em' ],
			'selectors'  => [
				'{{WRAPPER}} input' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		] );


		$this->end_controls_section();
		// </editor-fold>
	}

	protected function render() {
		global $inputs;

		if ( ! isset( $inputs ) ) {
			$inputs = [];
		}

		$settings = $this->get_settings_for_display();
		$type     = $settings['type'] ?? 'text';
		$label    = $settings['label'] ?? '';

		$inputName =
		$field = explode( '.', $settings['field'] ?? '' );

		$inputs[ array_shift( $inputName ) ][ array_shift( $inputName ) ] = '';

		$this->add_render_attribute( 'div', 'class', 'wrapper' );
		if ( ! empty( $settings['direction'] ) ) {
			$this->add_render_attribute( 'div', 'class', $settings['direction'] );
		}

		$this->add_render_attribute( 'input', 'type', $type );
		$this->add_render_attribute( 'input', 'name', sprintf( '[%s]', implode( '][', $field ) ) );

		if ( ! empty( $settings['placeholder'] ) ) {
			$this->add_render_attribute( 'input', 'placeholder', $settings['placeholder'] );
		}

		if ( filter_var( $settings['required'], FILTER_VALIDATE_BOOLEAN, FILTER_NULL_ON_FAILURE ) ?? false ) {
			$this->add_render_attribute( 'input', 'required', 'required' );
		}

		printf( '<div %s>', $this->get_render_attribute_string( 'div' ) );
		printf( '<label %2$s>%1$s</label>', $label, $this->get_render_attribute_string( 'label' ) );
		printf( '<input %s>', $this->get_render_attribute_string( 'input' ) );
		printf( '</div>' );
	}
}